# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
import grpc

from google.ads.google_ads.v1.proto.resources import google_ads_field_pb2 as google_dot_ads_dot_googleads__v1_dot_proto_dot_resources_dot_google__ads__field__pb2
from google.ads.google_ads.v1.proto.services import google_ads_field_service_pb2 as google_dot_ads_dot_googleads__v1_dot_proto_dot_services_dot_google__ads__field__service__pb2


class GoogleAdsFieldServiceStub(object):
  """Proto file describing the GoogleAdsFieldService

  Service to fetch Google Ads API fields.
  """

  def __init__(self, channel):
    """Constructor.

    Args:
      channel: A grpc.Channel.
    """
    self.GetGoogleAdsField = channel.unary_unary(
        '/google.ads.googleads.v1.services.GoogleAdsFieldService/GetGoogleAdsField',
        request_serializer=google_dot_ads_dot_googleads__v1_dot_proto_dot_services_dot_google__ads__field__service__pb2.GetGoogleAdsFieldRequest.SerializeToString,
        response_deserializer=google_dot_ads_dot_googleads__v1_dot_proto_dot_resources_dot_google__ads__field__pb2.GoogleAdsField.FromString,
        )
    self.SearchGoogleAdsFields = channel.unary_unary(
        '/google.ads.googleads.v1.services.GoogleAdsFieldService/SearchGoogleAdsFields',
        request_serializer=google_dot_ads_dot_googleads__v1_dot_proto_dot_services_dot_google__ads__field__service__pb2.SearchGoogleAdsFieldsRequest.SerializeToString,
        response_deserializer=google_dot_ads_dot_googleads__v1_dot_proto_dot_services_dot_google__ads__field__service__pb2.SearchGoogleAdsFieldsResponse.FromString,
        )


class GoogleAdsFieldServiceServicer(object):
  """Proto file describing the GoogleAdsFieldService

  Service to fetch Google Ads API fields.
  """

  def GetGoogleAdsField(self, request, context):
    """Returns just the requested field.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def SearchGoogleAdsFields(self, request, context):
    """Returns all fields that match the search query.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')


def add_GoogleAdsFieldServiceServicer_to_server(servicer, server):
  rpc_method_handlers = {
      'GetGoogleAdsField': grpc.unary_unary_rpc_method_handler(
          servicer.GetGoogleAdsField,
          request_deserializer=google_dot_ads_dot_googleads__v1_dot_proto_dot_services_dot_google__ads__field__service__pb2.GetGoogleAdsFieldRequest.FromString,
          response_serializer=google_dot_ads_dot_googleads__v1_dot_proto_dot_resources_dot_google__ads__field__pb2.GoogleAdsField.SerializeToString,
      ),
      'SearchGoogleAdsFields': grpc.unary_unary_rpc_method_handler(
          servicer.SearchGoogleAdsFields,
          request_deserializer=google_dot_ads_dot_googleads__v1_dot_proto_dot_services_dot_google__ads__field__service__pb2.SearchGoogleAdsFieldsRequest.FromString,
          response_serializer=google_dot_ads_dot_googleads__v1_dot_proto_dot_services_dot_google__ads__field__service__pb2.SearchGoogleAdsFieldsResponse.SerializeToString,
      ),
  }
  generic_handler = grpc.method_handlers_generic_handler(
      'google.ads.googleads.v1.services.GoogleAdsFieldService', rpc_method_handlers)
  server.add_generic_rpc_handlers((generic_handler,))



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/ads/googleads_v1/proto/errors/media_bundle_error.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='google/ads/googleads_v1/proto/errors/media_bundle_error.proto',
  package='google.ads.googleads.v1.errors',
  syntax='proto3',
  serialized_options=_b('\n\"com.google.ads.googleads.v1.errorsB\025MediaBundleErrorProtoP\001ZDgoogle.golang.org/genproto/googleapis/ads/googleads/v1/errors;errors\242\002\003GAA\252\002\036Google.Ads.GoogleAds.V1.Errors\312\002\036Google\\Ads\\GoogleAds\\V1\\Errors\352\002\"Google::Ads::GoogleAds::V1::Errors'),
  serialized_pb=_b('\n=google/ads/googleads_v1/proto/errors/media_bundle_error.proto\x12\x1egoogle.ads.googleads.v1.errors\x1a\x1cgoogle/api/annotations.proto\"\xb8\x05\n\x14MediaBundleErrorEnum\"\x9f\x05\n\x10MediaBundleError\x12\x0f\n\x0bUNSPECIFIED\x10\x00\x12\x0b\n\x07UNKNOWN\x10\x01\x12\x0f\n\x0b\x42\x41\x44_REQUEST\x10\x03\x12\"\n\x1e\x44OUBLECLICK_BUNDLE_NOT_ALLOWED\x10\x04\x12\x1c\n\x18\x45XTERNAL_URL_NOT_ALLOWED\x10\x05\x12\x12\n\x0e\x46ILE_TOO_LARGE\x10\x06\x12.\n*GOOGLE_WEB_DESIGNER_ZIP_FILE_NOT_PUBLISHED\x10\x07\x12\x11\n\rINVALID_INPUT\x10\x08\x12\x18\n\x14INVALID_MEDIA_BUNDLE\x10\t\x12\x1e\n\x1aINVALID_MEDIA_BUNDLE_ENTRY\x10\n\x12\x15\n\x11INVALID_MIME_TYPE\x10\x0b\x12\x10\n\x0cINVALID_PATH\x10\x0c\x12\x19\n\x15INVALID_URL_REFERENCE\x10\r\x12\x18\n\x14MEDIA_DATA_TOO_LARGE\x10\x0e\x12&\n\"MISSING_PRIMARY_MEDIA_BUNDLE_ENTRY\x10\x0f\x12\x10\n\x0cSERVER_ERROR\x10\x10\x12\x11\n\rSTORAGE_ERROR\x10\x11\x12\x1d\n\x19SWIFFY_BUNDLE_NOT_ALLOWED\x10\x12\x12\x12\n\x0eTOO_MANY_FILES\x10\x13\x12\x13\n\x0fUNEXPECTED_SIZE\x10\x14\x12/\n+UNSUPPORTED_GOOGLE_WEB_DESIGNER_ENVIRONMENT\x10\x15\x12\x1d\n\x19UNSUPPORTED_HTML5_FEATURE\x10\x16\x12)\n%URL_IN_MEDIA_BUNDLE_NOT_SSL_COMPLIANT\x10\x17\x12\x1b\n\x17\x43USTOM_EXIT_NOT_ALLOWED\x10\x18\x42\xf0\x01\n\"com.google.ads.googleads.v1.errorsB\x15MediaBundleErrorProtoP\x01ZDgoogle.golang.org/genproto/googleapis/ads/googleads/v1/errors;errors\xa2\x02\x03GAA\xaa\x02\x1eGoogle.Ads.GoogleAds.V1.Errors\xca\x02\x1eGoogle\\Ads\\GoogleAds\\V1\\Errors\xea\x02\"Google::Ads::GoogleAds::V1::Errorsb\x06proto3')
  ,
  dependencies=[google_dot_api_dot_annotations__pb2.DESCRIPTOR,])



_MEDIABUNDLEERRORENUM_MEDIABUNDLEERROR = _descriptor.EnumDescriptor(
  name='MediaBundleError',
  full_name='google.ads.googleads.v1.errors.MediaBundleErrorEnum.MediaBundleError',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='UNKNOWN', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='BAD_REQUEST', index=2, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DOUBLECLICK_BUNDLE_NOT_ALLOWED', index=3, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='EXTERNAL_URL_NOT_ALLOWED', index=4, number=5,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FILE_TOO_LARGE', index=5, number=6,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='GOOGLE_WEB_DESIGNER_ZIP_FILE_NOT_PUBLISHED', index=6, number=7,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INVALID_INPUT', index=7, number=8,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INVALID_MEDIA_BUNDLE', index=8, number=9,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INVALID_MEDIA_BUNDLE_ENTRY', index=9, number=10,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INVALID_MIME_TYPE', index=10, number=11,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INVALID_PATH', index=11, number=12,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INVALID_URL_REFERENCE', index=12, number=13,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MEDIA_DATA_TOO_LARGE', index=13, number=14,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MISSING_PRIMARY_MEDIA_BUNDLE_ENTRY', index=14, number=15,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SERVER_ERROR', index=15, number=16,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='STORAGE_ERROR', index=16, number=17,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SWIFFY_BUNDLE_NOT_ALLOWED', index=17, number=18,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='TOO_MANY_FILES', index=18, number=19,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='UNEXPECTED_SIZE', index=19, number=20,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='UNSUPPORTED_GOOGLE_WEB_DESIGNER_ENVIRONMENT', index=20, number=21,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='UNSUPPORTED_HTML5_FEATURE', index=21, number=22,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='URL_IN_MEDIA_BUNDLE_NOT_SSL_COMPLIANT', index=22, number=23,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CUSTOM_EXIT_NOT_ALLOWED', index=23, number=24,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=153,
  serialized_end=824,
)
_sym_db.RegisterEnumDescriptor(_MEDIABUNDLEERRORENUM_MEDIABUNDLEERROR)


_MEDIABUNDLEERRORENUM = _descriptor.Descriptor(
  name='MediaBundleErrorEnum',
  full_name='google.ads.googleads.v1.errors.MediaBundleErrorEnum',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _MEDIABUNDLEERRORENUM_MEDIABUNDLEERROR,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=128,
  serialized_end=824,
)

_MEDIABUNDLEERRORENUM_MEDIABUNDLEERROR.containing_type = _MEDIABUNDLEERRORENUM
DESCRIPTOR.message_types_by_name['MediaBundleErrorEnum'] = _MEDIABUNDLEERRORENUM
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

MediaBundleErrorEnum = _reflection.GeneratedProtocolMessageType('MediaBundleErrorEnum', (_message.Message,), dict(
  DESCRIPTOR = _MEDIABUNDLEERRORENUM,
  __module__ = 'google.ads.googleads_v1.proto.errors.media_bundle_error_pb2'
  ,
  __doc__ = """Container for enum describing possible media bundle errors.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v1.errors.MediaBundleErrorEnum)
  ))
_sym_db.RegisterMessage(MediaBundleErrorEnum)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/ads/googleads_v2/proto/resources/user_list.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.ads.google_ads.v2.proto.common import user_lists_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_common_dot_user__lists__pb2
from google.ads.google_ads.v2.proto.enums import access_reason_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_access__reason__pb2
from google.ads.google_ads.v2.proto.enums import user_list_access_status_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_user__list__access__status__pb2
from google.ads.google_ads.v2.proto.enums import user_list_closing_reason_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_user__list__closing__reason__pb2
from google.ads.google_ads.v2.proto.enums import user_list_membership_status_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_user__list__membership__status__pb2
from google.ads.google_ads.v2.proto.enums import user_list_size_range_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_user__list__size__range__pb2
from google.ads.google_ads.v2.proto.enums import user_list_type_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_user__list__type__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='google/ads/googleads_v2/proto/resources/user_list.proto',
  package='google.ads.googleads.v2.resources',
  syntax='proto3',
  serialized_options=_b('\n%com.google.ads.googleads.v2.resourcesB\rUserListProtoP\001ZJgoogle.golang.org/genproto/googleapis/ads/googleads/v2/resources;resources\242\002\003GAA\252\002!Google.Ads.GoogleAds.V2.Resources\312\002!Google\\Ads\\GoogleAds\\V2\\Resources\352\002%Google::Ads::GoogleAds::V2::Resources'),
  serialized_pb=_b('\n7google/ads/googleads_v2/proto/resources/user_list.proto\x12!google.ads.googleads.v2.resources\x1a\x35google/ads/googleads_v2/proto/common/user_lists.proto\x1a\x37google/ads/googleads_v2/proto/enums/access_reason.proto\x1a\x41google/ads/googleads_v2/proto/enums/user_list_access_status.proto\x1a\x42google/ads/googleads_v2/proto/enums/user_list_closing_reason.proto\x1a\x45google/ads/googleads_v2/proto/enums/user_list_membership_status.proto\x1a>google/ads/googleads_v2/proto/enums/user_list_size_range.proto\x1a\x38google/ads/googleads_v2/proto/enums/user_list_type.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1cgoogle/api/annotations.proto\"\x8f\r\n\x08UserList\x12\x15\n\rresource_name\x18\x01 \x01(\t\x12\'\n\x02id\x18\x02 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12-\n\tread_only\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12*\n\x04name\x18\x04 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x31\n\x0b\x64\x65scription\x18\x05 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12o\n\x11membership_status\x18\x06 \x01(\x0e\x32T.google.ads.googleads.v2.enums.UserListMembershipStatusEnum.UserListMembershipStatus\x12\x36\n\x10integration_code\x18\x07 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x39\n\x14membership_life_span\x18\x08 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12\x35\n\x10size_for_display\x18\t \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12\x66\n\x16size_range_for_display\x18\n \x01(\x0e\x32\x46.google.ads.googleads.v2.enums.UserListSizeRangeEnum.UserListSizeRange\x12\x34\n\x0fsize_for_search\x18\x0b \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12\x65\n\x15size_range_for_search\x18\x0c \x01(\x0e\x32\x46.google.ads.googleads.v2.enums.UserListSizeRangeEnum.UserListSizeRange\x12J\n\x04type\x18\r \x01(\x0e\x32<.google.ads.googleads.v2.enums.UserListTypeEnum.UserListType\x12\x66\n\x0e\x63losing_reason\x18\x0e \x01(\x0e\x32N.google.ads.googleads.v2.enums.UserListClosingReasonEnum.UserListClosingReason\x12S\n\raccess_reason\x18\x0f \x01(\x0e\x32<.google.ads.googleads.v2.enums.AccessReasonEnum.AccessReason\x12n\n\x18\x61\x63\x63ount_user_list_status\x18\x10 \x01(\x0e\x32L.google.ads.googleads.v2.enums.UserListAccessStatusEnum.UserListAccessStatus\x12\x37\n\x13\x65ligible_for_search\x18\x11 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x38\n\x14\x65ligible_for_display\x18\x12 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12S\n\x13\x63rm_based_user_list\x18\x13 \x01(\x0b\x32\x34.google.ads.googleads.v2.common.CrmBasedUserListInfoH\x00\x12P\n\x11similar_user_list\x18\x14 \x01(\x0b\x32\x33.google.ads.googleads.v2.common.SimilarUserListInfoH\x00\x12U\n\x14rule_based_user_list\x18\x15 \x01(\x0b\x32\x35.google.ads.googleads.v2.common.RuleBasedUserListInfoH\x00\x12P\n\x11logical_user_list\x18\x16 \x01(\x0b\x32\x33.google.ads.googleads.v2.common.LogicalUserListInfoH\x00\x12L\n\x0f\x62\x61sic_user_list\x18\x17 \x01(\x0b\x32\x31.google.ads.googleads.v2.common.BasicUserListInfoH\x00\x42\x0b\n\tuser_listB\xfa\x01\n%com.google.ads.googleads.v2.resourcesB\rUserListProtoP\x01ZJgoogle.golang.org/genproto/googleapis/ads/googleads/v2/resources;resources\xa2\x02\x03GAA\xaa\x02!Google.Ads.GoogleAds.V2.Resources\xca\x02!Google\\Ads\\GoogleAds\\V2\\Resources\xea\x02%Google::Ads::GoogleAds::V2::Resourcesb\x06proto3')
  ,
  dependencies=[google_dot_ads_dot_googleads__v2_dot_proto_dot_common_dot_user__lists__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_access__reason__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_user__list__access__status__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_user__list__closing__reason__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_user__list__membership__status__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_user__list__size__range__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_user__list__type__pb2.DESCRIPTOR,google_dot_protobuf_dot_wrappers__pb2.DESCRIPTOR,google_dot_api_dot_annotations__pb2.DESCRIPTOR,])




_USERLIST = _descriptor.Descriptor(
  name='UserList',
  full_name='google.ads.googleads.v2.resources.UserList',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='resource_name', full_name='google.ads.googleads.v2.resources.UserList.resource_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='id', full_name='google.ads.googleads.v2.resources.UserList.id', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='read_only', full_name='google.ads.googleads.v2.resources.UserList.read_only', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='name', full_name='google.ads.googleads.v2.resources.UserList.name', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='description', full_name='google.ads.googleads.v2.resources.UserList.description', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='membership_status', full_name='google.ads.googleads.v2.resources.UserList.membership_status', index=5,
      number=6, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='integration_code', full_name='google.ads.googleads.v2.resources.UserList.integration_code', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='membership_life_span', full_name='google.ads.googleads.v2.resources.UserList.membership_life_span', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='size_for_display', full_name='google.ads.googleads.v2.resources.UserList.size_for_display', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='size_range_for_display', full_name='google.ads.googleads.v2.resources.UserList.size_range_for_display', index=9,
      number=10, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='size_for_search', full_name='google.ads.googleads.v2.resources.UserList.size_for_search', index=10,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='size_range_for_search', full_name='google.ads.googleads.v2.resources.UserList.size_range_for_search', index=11,
      number=12, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='type', full_name='google.ads.googleads.v2.resources.UserList.type', index=12,
      number=13, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='closing_reason', full_name='google.ads.googleads.v2.resources.UserList.closing_reason', index=13,
      number=14, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='access_reason', full_name='google.ads.googleads.v2.resources.UserList.access_reason', index=14,
      number=15, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='account_user_list_status', full_name='google.ads.googleads.v2.resources.UserList.account_user_list_status', index=15,
      number=16, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='eligible_for_search', full_name='google.ads.googleads.v2.resources.UserList.eligible_for_search', index=16,
      number=17, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='eligible_for_display', full_name='google.ads.googleads.v2.resources.UserList.eligible_for_display', index=17,
      number=18, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='crm_based_user_list', full_name='google.ads.googleads.v2.resources.UserList.crm_based_user_list', index=18,
      number=19, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='similar_user_list', full_name='google.ads.googleads.v2.resources.UserList.similar_user_list', index=19,
      number=20, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='rule_based_user_list', full_name='google.ads.googleads.v2.resources.UserList.rule_based_user_list', index=20,
      number=21, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='logical_user_list', full_name='google.ads.googleads.v2.resources.UserList.logical_user_list', index=21,
      number=22, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='basic_user_list', full_name='google.ads.googleads.v2.resources.UserList.basic_user_list', index=22,
      number=23, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='user_list', full_name='google.ads.googleads.v2.resources.UserList.user_list',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=597,
  serialized_end=2276,
)

_USERLIST.fields_by_name['id'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_USERLIST.fields_by_name['read_only'].message_type = google_dot_protobuf_dot_wrappers__pb2._BOOLVALUE
_USERLIST.fields_by_name['name'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_USERLIST.fields_by_name['description'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_USERLIST.fields_by_name['membership_status'].enum_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_user__list__membership__status__pb2._USERLISTMEMBERSHIPSTATUSENUM_USERLISTMEMBERSHIPSTATUS
_USERLIST.fields_by_name['integration_code'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_USERLIST.fields_by_name['membership_life_span'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_USERLIST.fields_by_name['size_for_display'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_USERLIST.fields_by_name['size_range_for_display'].enum_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_user__list__size__range__pb2._USERLISTSIZERANGEENUM_USERLISTSIZERANGE
_USERLIST.fields_by_name['size_for_search'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_USERLIST.fields_by_name['size_range_for_search'].enum_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_user__list__size__range__pb2._USERLISTSIZERANGEENUM_USERLISTSIZERANGE
_USERLIST.fields_by_name['type'].enum_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_user__list__type__pb2._USERLISTTYPEENUM_USERLISTTYPE
_USERLIST.fields_by_name['closing_reason'].enum_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_user__list__closing__reason__pb2._USERLISTCLOSINGREASONENUM_USERLISTCLOSINGREASON
_USERLIST.fields_by_name['access_reason'].enum_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_access__reason__pb2._ACCESSREASONENUM_ACCESSREASON
_USERLIST.fields_by_name['account_user_list_status'].enum_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_user__list__access__status__pb2._USERLISTACCESSSTATUSENUM_USERLISTACCESSSTATUS
_USERLIST.fields_by_name['eligible_for_search'].message_type = google_dot_protobuf_dot_wrappers__pb2._BOOLVALUE
_USERLIST.fields_by_name['eligible_for_display'].message_type = google_dot_protobuf_dot_wrappers__pb2._BOOLVALUE
_USERLIST.fields_by_name['crm_based_user_list'].message_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_common_dot_user__lists__pb2._CRMBASEDUSERLISTINFO
_USERLIST.fields_by_name['similar_user_list'].message_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_common_dot_user__lists__pb2._SIMILARUSERLISTINFO
_USERLIST.fields_by_name['rule_based_user_list'].message_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_common_dot_user__lists__pb2._RULEBASEDUSERLISTINFO
_USERLIST.fields_by_name['logical_user_list'].message_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_common_dot_user__lists__pb2._LOGICALUSERLISTINFO
_USERLIST.fields_by_name['basic_user_list'].message_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_common_dot_user__lists__pb2._BASICUSERLISTINFO
_USERLIST.oneofs_by_name['user_list'].fields.append(
  _USERLIST.fields_by_name['crm_based_user_list'])
_USERLIST.fields_by_name['crm_based_user_list'].containing_oneof = _USERLIST.oneofs_by_name['user_list']
_USERLIST.oneofs_by_name['user_list'].fields.append(
  _USERLIST.fields_by_name['similar_user_list'])
_USERLIST.fields_by_name['similar_user_list'].containing_oneof = _USERLIST.oneofs_by_name['user_list']
_USERLIST.oneofs_by_name['user_list'].fields.append(
  _USERLIST.fields_by_name['rule_based_user_list'])
_USERLIST.fields_by_name['rule_based_user_list'].containing_oneof = _USERLIST.oneofs_by_name['user_list']
_USERLIST.oneofs_by_name['user_list'].fields.append(
  _USERLIST.fields_by_name['logical_user_list'])
_USERLIST.fields_by_name['logical_user_list'].containing_oneof = _USERLIST.oneofs_by_name['user_list']
_USERLIST.oneofs_by_name['user_list'].fields.append(
  _USERLIST.fields_by_name['basic_user_list'])
_USERLIST.fields_by_name['basic_user_list'].containing_oneof = _USERLIST.oneofs_by_name['user_list']
DESCRIPTOR.message_types_by_name['UserList'] = _USERLIST
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

UserList = _reflection.GeneratedProtocolMessageType('UserList', (_message.Message,), dict(
  DESCRIPTOR = _USERLIST,
  __module__ = 'google.ads.googleads_v2.proto.resources.user_list_pb2'
  ,
  __doc__ = """A user list. This is a list of users a customer may target.
  
  
  Attributes:
      resource_name:
          The resource name of the user list. User list resource names
          have the form:
          ``customers/{customer_id}/userLists/{user_list_id}``
      id:
          Id of the user list.
      read_only:
          A flag that indicates if a user may edit a list. Depends on
          the list ownership and list type. For example, external
          remarketing user lists are not editable.  This field is read-
          only.
      name:
          Name of this user list. Depending on its access\_reason, the
          user list name may not be unique (e.g. if
          access\_reason=SHARED)
      description:
          Description of this user list.
      membership_status:
          Membership status of this user list. Indicates whether a user
          list is open or active. Only open user lists can accumulate
          more users and can be targeted to.
      integration_code:
          An ID from external system. It is used by user list sellers to
          correlate IDs on their systems.
      membership_life_span:
          Number of days a user's cookie stays on your list since its
          most recent addition to the list. This field must be between 0
          and 540 inclusive. However, for CRM based userlists, this
          field can be set to 10000 which means no expiration.  It'll be
          ignored for logical\_user\_list.
      size_for_display:
          Estimated number of users in this user list, on the Google
          Display Network. This value is null if the number of users has
          not yet been determined.  This field is read-only.
      size_range_for_display:
          Size range in terms of number of users of the UserList, on the
          Google Display Network.  This field is read-only.
      size_for_search:
          Estimated number of users in this user list in the google.com
          domain. These are the users available for targeting in Search
          campaigns. This value is null if the number of users has not
          yet been determined.  This field is read-only.
      size_range_for_search:
          Size range in terms of number of users of the UserList, for
          Search ads.  This field is read-only.
      type:
          Type of this list.  This field is read-only.
      closing_reason:
          Indicating the reason why this user list membership status is
          closed. It is only populated on lists that were automatically
          closed due to inactivity, and will be cleared once the list
          membership status becomes open.
      access_reason:
          Indicates the reason this account has been granted access to
          the list. The reason can be SHARED, OWNED, LICENSED or
          SUBSCRIBED.  This field is read-only.
      account_user_list_status:
          Indicates if this share is still enabled. When a UserList is
          shared with the user this field is set to ENABLED. Later the
          userList owner can decide to revoke the share and make it
          DISABLED. The default value of this field is set to ENABLED.
      eligible_for_search:
          Indicates if this user list is eligible for Google Search
          Network.
      eligible_for_display:
          Indicates this user list is eligible for Google Display
          Network.  This field is read-only.
      user_list:
          The user list.  Exactly one must be set.
      crm_based_user_list:
          User list of CRM users provided by the advertiser.
      similar_user_list:
          User list which are similar to users from another UserList.
          These lists are readonly and automatically created by google.
      rule_based_user_list:
          User list generated by a rule.
      logical_user_list:
          User list that is a custom combination of user lists and user
          interests.
      basic_user_list:
          User list targeting as a collection of conversion or
          remarketing actions.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v2.resources.UserList)
  ))
_sym_db.RegisterMessage(UserList)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/ads/googleads_v2/proto/services/media_file_service.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.ads.google_ads.v2.proto.resources import media_file_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_media__file__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.rpc import status_pb2 as google_dot_rpc_dot_status__pb2
from google.api import client_pb2 as google_dot_api_dot_client__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='google/ads/googleads_v2/proto/services/media_file_service.proto',
  package='google.ads.googleads.v2.services',
  syntax='proto3',
  serialized_options=_b('\n$com.google.ads.googleads.v2.servicesB\025MediaFileServiceProtoP\001ZHgoogle.golang.org/genproto/googleapis/ads/googleads/v2/services;services\242\002\003GAA\252\002 Google.Ads.GoogleAds.V2.Services\312\002 Google\\Ads\\GoogleAds\\V2\\Services\352\002$Google::Ads::GoogleAds::V2::Services'),
  serialized_pb=_b('\n?google/ads/googleads_v2/proto/services/media_file_service.proto\x12 google.ads.googleads.v2.services\x1a\x38google/ads/googleads_v2/proto/resources/media_file.proto\x1a\x1cgoogle/api/annotations.proto\x1a\x17google/rpc/status.proto\x1a\x17google/api/client.proto\",\n\x13GetMediaFileRequest\x12\x15\n\rresource_name\x18\x01 \x01(\t\"\xa8\x01\n\x17MutateMediaFilesRequest\x12\x13\n\x0b\x63ustomer_id\x18\x01 \x01(\t\x12H\n\noperations\x18\x02 \x03(\x0b\x32\x34.google.ads.googleads.v2.services.MediaFileOperation\x12\x17\n\x0fpartial_failure\x18\x03 \x01(\x08\x12\x15\n\rvalidate_only\x18\x04 \x01(\x08\"a\n\x12MediaFileOperation\x12>\n\x06\x63reate\x18\x01 \x01(\x0b\x32,.google.ads.googleads.v2.resources.MediaFileH\x00\x42\x0b\n\toperation\"\x97\x01\n\x18MutateMediaFilesResponse\x12\x31\n\x15partial_failure_error\x18\x03 \x01(\x0b\x32\x12.google.rpc.Status\x12H\n\x07results\x18\x02 \x03(\x0b\x32\x37.google.ads.googleads.v2.services.MutateMediaFileResult\".\n\x15MutateMediaFileResult\x12\x15\n\rresource_name\x18\x01 \x01(\t2\xa3\x03\n\x10MediaFileService\x12\xa9\x01\n\x0cGetMediaFile\x12\x35.google.ads.googleads.v2.services.GetMediaFileRequest\x1a,.google.ads.googleads.v2.resources.MediaFile\"4\x82\xd3\xe4\x93\x02.\x12,/v2/{resource_name=customers/*/mediaFiles/*}\x12\xc5\x01\n\x10MutateMediaFiles\x12\x39.google.ads.googleads.v2.services.MutateMediaFilesRequest\x1a:.google.ads.googleads.v2.services.MutateMediaFilesResponse\":\x82\xd3\xe4\x93\x02\x34\"//v2/customers/{customer_id=*}/mediaFiles:mutate:\x01*\x1a\x1b\xca\x41\x18googleads.googleapis.comB\xfc\x01\n$com.google.ads.googleads.v2.servicesB\x15MediaFileServiceProtoP\x01ZHgoogle.golang.org/genproto/googleapis/ads/googleads/v2/services;services\xa2\x02\x03GAA\xaa\x02 Google.Ads.GoogleAds.V2.Services\xca\x02 Google\\Ads\\GoogleAds\\V2\\Services\xea\x02$Google::Ads::GoogleAds::V2::Servicesb\x06proto3')
  ,
  dependencies=[google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_media__file__pb2.DESCRIPTOR,google_dot_api_dot_annotations__pb2.DESCRIPTOR,google_dot_rpc_dot_status__pb2.DESCRIPTOR,google_dot_api_dot_client__pb2.DESCRIPTOR,])




_GETMEDIAFILEREQUEST = _descriptor.Descriptor(
  name='GetMediaFileRequest',
  full_name='google.ads.googleads.v2.services.GetMediaFileRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='resource_name', full_name='google.ads.googleads.v2.services.GetMediaFileRequest.resource_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=239,
  serialized_end=283,
)


_MUTATEMEDIAFILESREQUEST = _descriptor.Descriptor(
  name='MutateMediaFilesRequest',
  full_name='google.ads.googleads.v2.services.MutateMediaFilesRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='customer_id', full_name='google.ads.googleads.v2.services.MutateMediaFilesRequest.customer_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='operations', full_name='google.ads.googleads.v2.services.MutateMediaFilesRequest.operations', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='partial_failure', full_name='google.ads.googleads.v2.services.MutateMediaFilesRequest.partial_failure', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='validate_only', full_name='google.ads.googleads.v2.services.MutateMediaFilesRequest.validate_only', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=286,
  serialized_end=454,
)


_MEDIAFILEOPERATION = _descriptor.Descriptor(
  name='MediaFileOperation',
  full_name='google.ads.googleads.v2.services.MediaFileOperation',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='create', full_name='google.ads.googleads.v2.services.MediaFileOperation.create', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='operation', full_name='google.ads.googleads.v2.services.MediaFileOperation.operation',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=456,
  serialized_end=553,
)


_MUTATEMEDIAFILESRESPONSE = _descriptor.Descriptor(
  name='MutateMediaFilesResponse',
  full_name='google.ads.googleads.v2.services.MutateMediaFilesResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='partial_failure_error', full_name='google.ads.googleads.v2.services.MutateMediaFilesResponse.partial_failure_error', index=0,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='results', full_name='google.ads.googleads.v2.services.MutateMediaFilesResponse.results', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=556,
  serialized_end=707,
)


_MUTATEMEDIAFILERESULT = _descriptor.Descriptor(
  name='MutateMediaFileResult',
  full_name='google.ads.googleads.v2.services.MutateMediaFileResult',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='resource_name', full_name='google.ads.googleads.v2.services.MutateMediaFileResult.resource_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=709,
  serialized_end=755,
)

_MUTATEMEDIAFILESREQUEST.fields_by_name['operations'].message_type = _MEDIAFILEOPERATION
_MEDIAFILEOPERATION.fields_by_name['create'].message_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_media__file__pb2._MEDIAFILE
_MEDIAFILEOPERATION.oneofs_by_name['operation'].fields.append(
  _MEDIAFILEOPERATION.fields_by_name['create'])
_MEDIAFILEOPERATION.fields_by_name['create'].containing_oneof = _MEDIAFILEOPERATION.oneofs_by_name['operation']
_MUTATEMEDIAFILESRESPONSE.fields_by_name['partial_failure_error'].message_type = google_dot_rpc_dot_status__pb2._STATUS
_MUTATEMEDIAFILESRESPONSE.fields_by_name['results'].message_type = _MUTATEMEDIAFILERESULT
DESCRIPTOR.message_types_by_name['GetMediaFileRequest'] = _GETMEDIAFILEREQUEST
DESCRIPTOR.message_types_by_name['MutateMediaFilesRequest'] = _MUTATEMEDIAFILESREQUEST
DESCRIPTOR.message_types_by_name['MediaFileOperation'] = _MEDIAFILEOPERATION
DESCRIPTOR.message_types_by_name['MutateMediaFilesResponse'] = _MUTATEMEDIAFILESRESPONSE
DESCRIPTOR.message_types_by_name['MutateMediaFileResult'] = _MUTATEMEDIAFILERESULT
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

GetMediaFileRequest = _reflection.GeneratedProtocolMessageType('GetMediaFileRequest', (_message.Message,), dict(
  DESCRIPTOR = _GETMEDIAFILEREQUEST,
  __module__ = 'google.ads.googleads_v2.proto.services.media_file_service_pb2'
  ,
  __doc__ = """Request message for
  [MediaFileService.GetMediaFile][google.ads.googleads.v2.services.MediaFileService.GetMediaFile]
  
  
  Attributes:
      resource_name:
          The resource name of the media file to fetch.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v2.services.GetMediaFileRequest)
  ))
_sym_db.RegisterMessage(GetMediaFileRequest)

MutateMediaFilesRequest = _reflection.GeneratedProtocolMessageType('MutateMediaFilesRequest', (_message.Message,), dict(
  DESCRIPTOR = _MUTATEMEDIAFILESREQUEST,
  __module__ = 'google.ads.googleads_v2.proto.services.media_file_service_pb2'
  ,
  __doc__ = """Request message for
  [MediaFileService.MutateMediaFiles][google.ads.googleads.v2.services.MediaFileService.MutateMediaFiles]
  
  
  Attributes:
      customer_id:
          The ID of the customer whose media files are being modified.
      operations:
          The list of operations to perform on individual media file.
      partial_failure:
          If true, successful operations will be carried out and invalid
          operations will return errors. If false, all operations will
          be carried out in one transaction if and only if they are all
          valid. Default is false.
      validate_only:
          If true, the request is validated but not executed. Only
          errors are returned, not results.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v2.services.MutateMediaFilesRequest)
  ))
_sym_db.RegisterMessage(MutateMediaFilesRequest)

MediaFileOperation = _reflection.GeneratedProtocolMessageType('MediaFileOperation', (_message.Message,), dict(
  DESCRIPTOR = _MEDIAFILEOPERATION,
  __module__ = 'google.ads.googleads_v2.proto.services.media_file_service_pb2'
  ,
  __doc__ = """A single operation to create media file.
  
  
  Attributes:
      operation:
          The mutate operation.
      create:
          Create operation: No resource name is expected for the new
          media file.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v2.services.MediaFileOperation)
  ))
_sym_db.RegisterMessage(MediaFileOperation)

MutateMediaFilesResponse = _reflection.GeneratedProtocolMessageType('MutateMediaFilesResponse', (_message.Message,), dict(
  DESCRIPTOR = _MUTATEMEDIAFILESRESPONSE,
  __module__ = 'google.ads.googleads_v2.proto.services.media_file_service_pb2'
  ,
  __doc__ = """Response message for a media file mutate.
  
  
  Attributes:
      partial_failure_error:
          Errors that pertain to operation failures in the partial
          failure mode. Returned only when partial\_failure = true and
          all errors occur inside the operations. If any errors occur
          outside the operations (e.g. auth errors), we return an RPC
          level error.
      results:
          All results for the mutate.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v2.services.MutateMediaFilesResponse)
  ))
_sym_db.RegisterMessage(MutateMediaFilesResponse)

MutateMediaFileResult = _reflection.GeneratedProtocolMessageType('MutateMediaFileResult', (_message.Message,), dict(
  DESCRIPTOR = _MUTATEMEDIAFILERESULT,
  __module__ = 'google.ads.googleads_v2.proto.services.media_file_service_pb2'
  ,
  __doc__ = """The result for the media file mutate.
  
  
  Attributes:
      resource_name:
          The resource name returned for successful operations.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v2.services.MutateMediaFileResult)
  ))
_sym_db.RegisterMessage(MutateMediaFileResult)


DESCRIPTOR._options = None

_MEDIAFILESERVICE = _descriptor.ServiceDescriptor(
  name='MediaFileService',
  full_name='google.ads.googleads.v2.services.MediaFileService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=_b('\312A\030googleads.googleapis.com'),
  serialized_start=758,
  serialized_end=1177,
  methods=[
  _descriptor.MethodDescriptor(
    name='GetMediaFile',
    full_name='google.ads.googleads.v2.services.MediaFileService.GetMediaFile',
    index=0,
    containing_service=None,
    input_type=_GETMEDIAFILEREQUEST,
    output_type=google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_media__file__pb2._MEDIAFILE,
    serialized_options=_b('\202\323\344\223\002.\022,/v2/{resource_name=customers/*/mediaFiles/*}'),
  ),
  _descriptor.MethodDescriptor(
    name='MutateMediaFiles',
    full_name='google.ads.googleads.v2.services.MediaFileService.MutateMediaFiles',
    index=1,
    containing_service=None,
    input_type=_MUTATEMEDIAFILESREQUEST,
    output_type=_MUTATEMEDIAFILESRESPONSE,
    serialized_options=_b('\202\323\344\223\0024\"//v2/customers/{customer_id=*}/mediaFiles:mutate:\001*'),
  ),
])
_sym_db.RegisterServiceDescriptor(_MEDIAFILESERVICE)

DESCRIPTOR.services_by_name['MediaFileService'] = _MEDIAFILESERVICE

# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
import grpc

from google.ads.google_ads.v2.proto.resources import customer_extension_setting_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_customer__extension__setting__pb2
from google.ads.google_ads.v2.proto.services import customer_extension_setting_service_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_customer__extension__setting__service__pb2


class CustomerExtensionSettingServiceStub(object):
  """Proto file describing the CustomerExtensionSetting service.

  Service to manage customer extension settings.
  """

  def __init__(self, channel):
    """Constructor.

    Args:
      channel: A grpc.Channel.
    """
    self.GetCustomerExtensionSetting = channel.unary_unary(
        '/google.ads.googleads.v2.services.CustomerExtensionSettingService/GetCustomerExtensionSetting',
        request_serializer=google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_customer__extension__setting__service__pb2.GetCustomerExtensionSettingRequest.SerializeToString,
        response_deserializer=google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_customer__extension__setting__pb2.CustomerExtensionSetting.FromString,
        )
    self.MutateCustomerExtensionSettings = channel.unary_unary(
        '/google.ads.googleads.v2.services.CustomerExtensionSettingService/MutateCustomerExtensionSettings',
        request_serializer=google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_customer__extension__setting__service__pb2.MutateCustomerExtensionSettingsRequest.SerializeToString,
        response_deserializer=google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_customer__extension__setting__service__pb2.MutateCustomerExtensionSettingsResponse.FromString,
        )


class CustomerExtensionSettingServiceServicer(object):
  """Proto file describing the CustomerExtensionSetting service.

  Service to manage customer extension settings.
  """

  def GetCustomerExtensionSetting(self, request, context):
    """Returns the requested customer extension setting in full detail.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def MutateCustomerExtensionSettings(self, request, context):
    """Creates, updates, or removes customer extension settings. Operation
    statuses are returned.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')


def add_CustomerExtensionSettingServiceServicer_to_server(servicer, server):
  rpc_method_handlers = {
      'GetCustomerExtensionSetting': grpc.unary_unary_rpc_method_handler(
          servicer.GetCustomerExtensionSetting,
          request_deserializer=google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_customer__extension__setting__service__pb2.GetCustomerExtensionSettingRequest.FromString,
          response_serializer=google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_customer__extension__setting__pb2.CustomerExtensionSetting.SerializeToString,
      ),
      'MutateCustomerExtensionSettings': grpc.unary_unary_rpc_method_handler(
          servicer.MutateCustomerExtensionSettings,
          request_deserializer=google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_customer__extension__setting__service__pb2.MutateCustomerExtensionSettingsRequest.FromString,
          response_serializer=google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_customer__extension__setting__service__pb2.MutateCustomerExtensionSettingsResponse.SerializeToString,
      ),
  }
  generic_handler = grpc.method_handlers_generic_handler(
      'google.ads.googleads.v2.services.CustomerExtensionSettingService', rpc_method_handlers)
  server.add_generic_rpc_handlers((generic_handler,))



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/ads/googleads_v2/proto/errors/function_error.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='google/ads/googleads_v2/proto/errors/function_error.proto',
  package='google.ads.googleads.v2.errors',
  syntax='proto3',
  serialized_options=_b('\n\"com.google.ads.googleads.v2.errorsB\022FunctionErrorProtoP\001ZDgoogle.golang.org/genproto/googleapis/ads/googleads/v2/errors;errors\242\002\003GAA\252\002\036Google.Ads.GoogleAds.V2.Errors\312\002\036Google\\Ads\\GoogleAds\\V2\\Errors\352\002\"Google::Ads::GoogleAds::V2::Errors'),
  serialized_pb=_b('\n9google/ads/googleads_v2/proto/errors/function_error.proto\x12\x1egoogle.ads.googleads.v2.errors\x1a\x1cgoogle/api/annotations.proto\"\xc1\x04\n\x11\x46unctionErrorEnum\"\xab\x04\n\rFunctionError\x12\x0f\n\x0bUNSPECIFIED\x10\x00\x12\x0b\n\x07UNKNOWN\x10\x01\x12\x1b\n\x17INVALID_FUNCTION_FORMAT\x10\x02\x12\x16\n\x12\x44\x41TA_TYPE_MISMATCH\x10\x03\x12 \n\x1cINVALID_CONJUNCTION_OPERANDS\x10\x04\x12\x1e\n\x1aINVALID_NUMBER_OF_OPERANDS\x10\x05\x12\x18\n\x14INVALID_OPERAND_TYPE\x10\x06\x12\x14\n\x10INVALID_OPERATOR\x10\x07\x12 \n\x1cINVALID_REQUEST_CONTEXT_TYPE\x10\x08\x12)\n%INVALID_FUNCTION_FOR_CALL_PLACEHOLDER\x10\t\x12$\n INVALID_FUNCTION_FOR_PLACEHOLDER\x10\n\x12\x13\n\x0fINVALID_OPERAND\x10\x0b\x12\"\n\x1eMISSING_CONSTANT_OPERAND_VALUE\x10\x0c\x12\"\n\x1eINVALID_CONSTANT_OPERAND_VALUE\x10\r\x12\x13\n\x0fINVALID_NESTING\x10\x0e\x12#\n\x1fMULTIPLE_FEED_IDS_NOT_SUPPORTED\x10\x0f\x12/\n+INVALID_FUNCTION_FOR_FEED_WITH_FIXED_SCHEMA\x10\x10\x12\x1a\n\x16INVALID_ATTRIBUTE_NAME\x10\x11\x42\xed\x01\n\"com.google.ads.googleads.v2.errorsB\x12\x46unctionErrorProtoP\x01ZDgoogle.golang.org/genproto/googleapis/ads/googleads/v2/errors;errors\xa2\x02\x03GAA\xaa\x02\x1eGoogle.Ads.GoogleAds.V2.Errors\xca\x02\x1eGoogle\\Ads\\GoogleAds\\V2\\Errors\xea\x02\"Google::Ads::GoogleAds::V2::Errorsb\x06proto3')
  ,
  dependencies=[google_dot_api_dot_annotations__pb2.DESCRIPTOR,])



_FUNCTIONERRORENUM_FUNCTIONERROR = _descriptor.EnumDescriptor(
  name='FunctionError',
  full_name='google.ads.googleads.v2.errors.FunctionErrorEnum.FunctionError',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='UNKNOWN', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INVALID_FUNCTION_FORMAT', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DATA_TYPE_MISMATCH', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INVALID_CONJUNCTION_OPERANDS', index=4, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INVALID_NUMBER_OF_OPERANDS', index=5, number=5,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INVALID_OPERAND_TYPE', index=6, number=6,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INVALID_OPERATOR', index=7, number=7,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INVALID_REQUEST_CONTEXT_TYPE', index=8, number=8,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INVALID_FUNCTION_FOR_CALL_PLACEHOLDER', index=9, number=9,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INVALID_FUNCTION_FOR_PLACEHOLDER', index=10, number=10,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INVALID_OPERAND', index=11, number=11,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MISSING_CONSTANT_OPERAND_VALUE', index=12, number=12,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INVALID_CONSTANT_OPERAND_VALUE', index=13, number=13,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INVALID_NESTING', index=14, number=14,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MULTIPLE_FEED_IDS_NOT_SUPPORTED', index=15, number=15,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INVALID_FUNCTION_FOR_FEED_WITH_FIXED_SCHEMA', index=16, number=16,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INVALID_ATTRIBUTE_NAME', index=17, number=17,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=146,
  serialized_end=701,
)
_sym_db.RegisterEnumDescriptor(_FUNCTIONERRORENUM_FUNCTIONERROR)


_FUNCTIONERRORENUM = _descriptor.Descriptor(
  name='FunctionErrorEnum',
  full_name='google.ads.googleads.v2.errors.FunctionErrorEnum',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _FUNCTIONERRORENUM_FUNCTIONERROR,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=124,
  serialized_end=701,
)

_FUNCTIONERRORENUM_FUNCTIONERROR.containing_type = _FUNCTIONERRORENUM
DESCRIPTOR.message_types_by_name['FunctionErrorEnum'] = _FUNCTIONERRORENUM
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

FunctionErrorEnum = _reflection.GeneratedProtocolMessageType('FunctionErrorEnum', (_message.Message,), dict(
  DESCRIPTOR = _FUNCTIONERRORENUM,
  __module__ = 'google.ads.googleads_v2.proto.errors.function_error_pb2'
  ,
  __doc__ = """Container for enum describing possible function errors.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v2.errors.FunctionErrorEnum)
  ))
_sym_db.RegisterMessage(FunctionErrorEnum)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/ads/googleads_v2/proto/services/conversion_upload_service.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from google.rpc import status_pb2 as google_dot_rpc_dot_status__pb2
from google.api import client_pb2 as google_dot_api_dot_client__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='google/ads/googleads_v2/proto/services/conversion_upload_service.proto',
  package='google.ads.googleads.v2.services',
  syntax='proto3',
  serialized_options=_b('\n$com.google.ads.googleads.v2.servicesB\034ConversionUploadServiceProtoP\001ZHgoogle.golang.org/genproto/googleapis/ads/googleads/v2/services;services\242\002\003GAA\252\002 Google.Ads.GoogleAds.V2.Services\312\002 Google\\Ads\\GoogleAds\\V2\\Services\352\002$Google::Ads::GoogleAds::V2::Services'),
  serialized_pb=_b('\nFgoogle/ads/googleads_v2/proto/services/conversion_upload_service.proto\x12 google.ads.googleads.v2.services\x1a\x1cgoogle/api/annotations.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x17google/rpc/status.proto\x1a\x17google/api/client.proto\"\xac\x01\n\x1dUploadClickConversionsRequest\x12\x13\n\x0b\x63ustomer_id\x18\x01 \x01(\t\x12\x46\n\x0b\x63onversions\x18\x02 \x03(\x0b\x32\x31.google.ads.googleads.v2.services.ClickConversion\x12\x17\n\x0fpartial_failure\x18\x03 \x01(\x08\x12\x15\n\rvalidate_only\x18\x04 \x01(\x08\"\x9d\x01\n\x1eUploadClickConversionsResponse\x12\x31\n\x15partial_failure_error\x18\x01 \x01(\x0b\x32\x12.google.rpc.Status\x12H\n\x07results\x18\x02 \x03(\x0b\x32\x37.google.ads.googleads.v2.services.ClickConversionResult\"\xaa\x01\n\x1cUploadCallConversionsRequest\x12\x13\n\x0b\x63ustomer_id\x18\x01 \x01(\t\x12\x45\n\x0b\x63onversions\x18\x02 \x03(\x0b\x32\x30.google.ads.googleads.v2.services.CallConversion\x12\x17\n\x0fpartial_failure\x18\x03 \x01(\x08\x12\x15\n\rvalidate_only\x18\x04 \x01(\x08\"\x9b\x01\n\x1dUploadCallConversionsResponse\x12\x31\n\x15partial_failure_error\x18\x01 \x01(\x0b\x32\x12.google.rpc.Status\x12G\n\x07results\x18\x02 \x03(\x0b\x32\x36.google.ads.googleads.v2.services.CallConversionResult\"\xae\x03\n\x0f\x43lickConversion\x12+\n\x05gclid\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x37\n\x11\x63onversion_action\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12:\n\x14\x63onversion_date_time\x18\x03 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x36\n\x10\x63onversion_value\x18\x04 \x01(\x0b\x32\x1c.google.protobuf.DoubleValue\x12\x33\n\rcurrency_code\x18\x05 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12.\n\x08order_id\x18\x06 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\\\n\x19\x65xternal_attribution_data\x18\x07 \x01(\x0b\x32\x39.google.ads.googleads.v2.services.ExternalAttributionData\"\xdf\x02\n\x0e\x43\x61llConversion\x12/\n\tcaller_id\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12:\n\x14\x63\x61ll_start_date_time\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x37\n\x11\x63onversion_action\x18\x03 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12:\n\x14\x63onversion_date_time\x18\x04 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x36\n\x10\x63onversion_value\x18\x05 \x01(\x0b\x32\x1c.google.protobuf.DoubleValue\x12\x33\n\rcurrency_code\x18\x06 \x01(\x0b\x32\x1c.google.protobuf.StringValue\"\x9e\x01\n\x17\x45xternalAttributionData\x12\x41\n\x1b\x65xternal_attribution_credit\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.DoubleValue\x12@\n\x1a\x65xternal_attribution_model\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.StringValue\"\xb9\x01\n\x15\x43lickConversionResult\x12+\n\x05gclid\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x37\n\x11\x63onversion_action\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12:\n\x14\x63onversion_date_time\x18\x03 \x01(\x0b\x32\x1c.google.protobuf.StringValue\"\xf8\x01\n\x14\x43\x61llConversionResult\x12/\n\tcaller_id\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12:\n\x14\x63\x61ll_start_date_time\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x37\n\x11\x63onversion_action\x18\x03 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12:\n\x14\x63onversion_date_time\x18\x04 \x01(\x0b\x32\x1c.google.protobuf.StringValue2\xf0\x03\n\x17\x43onversionUploadService\x12\xdc\x01\n\x16UploadClickConversions\x12?.google.ads.googleads.v2.services.UploadClickConversionsRequest\x1a@.google.ads.googleads.v2.services.UploadClickConversionsResponse\"?\x82\xd3\xe4\x93\x02\x39\"4/v2/customers/{customer_id=*}:uploadClickConversions:\x01*\x12\xd8\x01\n\x15UploadCallConversions\x12>.google.ads.googleads.v2.services.UploadCallConversionsRequest\x1a?.google.ads.googleads.v2.services.UploadCallConversionsResponse\">\x82\xd3\xe4\x93\x02\x38\"3/v2/customers/{customer_id=*}:uploadCallConversions:\x01*\x1a\x1b\xca\x41\x18googleads.googleapis.comB\x83\x02\n$com.google.ads.googleads.v2.servicesB\x1c\x43onversionUploadServiceProtoP\x01ZHgoogle.golang.org/genproto/googleapis/ads/googleads/v2/services;services\xa2\x02\x03GAA\xaa\x02 Google.Ads.GoogleAds.V2.Services\xca\x02 Google\\Ads\\GoogleAds\\V2\\Services\xea\x02$Google::Ads::GoogleAds::V2::Servicesb\x06proto3')
  ,
  dependencies=[google_dot_api_dot_annotations__pb2.DESCRIPTOR,google_dot_protobuf_dot_wrappers__pb2.DESCRIPTOR,google_dot_rpc_dot_status__pb2.DESCRIPTOR,google_dot_api_dot_client__pb2.DESCRIPTOR,])




_UPLOADCLICKCONVERSIONSREQUEST = _descriptor.Descriptor(
  name='UploadClickConversionsRequest',
  full_name='google.ads.googleads.v2.services.UploadClickConversionsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='customer_id', full_name='google.ads.googleads.v2.services.UploadClickConversionsRequest.customer_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='conversions', full_name='google.ads.googleads.v2.services.UploadClickConversionsRequest.conversions', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='partial_failure', full_name='google.ads.googleads.v2.services.UploadClickConversionsRequest.partial_failure', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='validate_only', full_name='google.ads.googleads.v2.services.UploadClickConversionsRequest.validate_only', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=221,
  serialized_end=393,
)


_UPLOADCLICKCONVERSIONSRESPONSE = _descriptor.Descriptor(
  name='UploadClickConversionsResponse',
  full_name='google.ads.googleads.v2.services.UploadClickConversionsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='partial_failure_error', full_name='google.ads.googleads.v2.services.UploadClickConversionsResponse.partial_failure_error', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='results', full_name='google.ads.googleads.v2.services.UploadClickConversionsResponse.results', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=396,
  serialized_end=553,
)


_UPLOADCALLCONVERSIONSREQUEST = _descriptor.Descriptor(
  name='UploadCallConversionsRequest',
  full_name='google.ads.googleads.v2.services.UploadCallConversionsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='customer_id', full_name='google.ads.googleads.v2.services.UploadCallConversionsRequest.customer_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='conversions', full_name='google.ads.googleads.v2.services.UploadCallConversionsRequest.conversions', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='partial_failure', full_name='google.ads.googleads.v2.services.UploadCallConversionsRequest.partial_failure', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='validate_only', full_name='google.ads.googleads.v2.services.UploadCallConversionsRequest.validate_only', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=556,
  serialized_end=726,
)


_UPLOADCALLCONVERSIONSRESPONSE = _descriptor.Descriptor(
  name='UploadCallConversionsResponse',
  full_name='google.ads.googleads.v2.services.UploadCallConversionsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='partial_failure_error', full_name='google.ads.googleads.v2.services.UploadCallConversionsResponse.partial_failure_error', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='results', full_name='google.ads.googleads.v2.services.UploadCallConversionsResponse.results', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=729,
  serialized_end=884,
)


_CLICKCONVERSION = _descriptor.Descriptor(
  name='ClickConversion',
  full_name='google.ads.googleads.v2.services.ClickConversion',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='gclid', full_name='google.ads.googleads.v2.services.ClickConversion.gclid', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='conversion_action', full_name='google.ads.googleads.v2.services.ClickConversion.conversion_action', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='conversion_date_time', full_name='google.ads.googleads.v2.services.ClickConversion.conversion_date_time', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='conversion_value', full_name='google.ads.googleads.v2.services.ClickConversion.conversion_value', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='currency_code', full_name='google.ads.googleads.v2.services.ClickConversion.currency_code', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='order_id', full_name='google.ads.googleads.v2.services.ClickConversion.order_id', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='external_attribution_data', full_name='google.ads.googleads.v2.services.ClickConversion.external_attribution_data', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=887,
  serialized_end=1317,
)


_CALLCONVERSION = _descriptor.Descriptor(
  name='CallConversion',
  full_name='google.ads.googleads.v2.services.CallConversion',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='caller_id', full_name='google.ads.googleads.v2.services.CallConversion.caller_id', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='call_start_date_time', full_name='google.ads.googleads.v2.services.CallConversion.call_start_date_time', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='conversion_action', full_name='google.ads.googleads.v2.services.CallConversion.conversion_action', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='conversion_date_time', full_name='google.ads.googleads.v2.services.CallConversion.conversion_date_time', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='conversion_value', full_name='google.ads.googleads.v2.services.CallConversion.conversion_value', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='currency_code', full_name='google.ads.googleads.v2.services.CallConversion.currency_code', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1320,
  serialized_end=1671,
)


_EXTERNALATTRIBUTIONDATA = _descriptor.Descriptor(
  name='ExternalAttributionData',
  full_name='google.ads.googleads.v2.services.ExternalAttributionData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='external_attribution_credit', full_name='google.ads.googleads.v2.services.ExternalAttributionData.external_attribution_credit', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='external_attribution_model', full_name='google.ads.googleads.v2.services.ExternalAttributionData.external_attribution_model', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1674,
  serialized_end=1832,
)


_CLICKCONVERSIONRESULT = _descriptor.Descriptor(
  name='ClickConversionResult',
  full_name='google.ads.googleads.v2.services.ClickConversionResult',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='gclid', full_name='google.ads.googleads.v2.services.ClickConversionResult.gclid', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='conversion_action', full_name='google.ads.googleads.v2.services.ClickConversionResult.conversion_action', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='conversion_date_time', full_name='google.ads.googleads.v2.services.ClickConversionResult.conversion_date_time', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1835,
  serialized_end=2020,
)


_CALLCONVERSIONRESULT = _descriptor.Descriptor(
  name='CallConversionResult',
  full_name='google.ads.googleads.v2.services.CallConversionResult',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='caller_id', full_name='google.ads.googleads.v2.services.CallConversionResult.caller_id', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='call_start_date_time', full_name='google.ads.googleads.v2.services.CallConversionResult.call_start_date_time', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='conversion_action', full_name='google.ads.googleads.v2.services.CallConversionResult.conversion_action', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='conversion_date_time', full_name='google.ads.googleads.v2.services.CallConversionResult.conversion_date_time', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2023,
  serialized_end=2271,
)

_UPLOADCLICKCONVERSIONSREQUEST.fields_by_name['conversions'].message_type = _CLICKCONVERSION
_UPLOADCLICKCONVERSIONSRESPONSE.fields_by_name['partial_failure_error'].message_type = google_dot_rpc_dot_status__pb2._STATUS
_UPLOADCLICKCONVERSIONSRESPONSE.fields_by_name['results'].message_type = _CLICKCONVERSIONRESULT
_UPLOADCALLCONVERSIONSREQUEST.fields_by_name['conversions'].message_type = _CALLCONVERSION
_UPLOADCALLCONVERSIONSRESPONSE.fields_by_name['partial_failure_error'].message_type = google_dot_rpc_dot_status__pb2._STATUS
_UPLOADCALLCONVERSIONSRESPONSE.fields_by_name['results'].message_type = _CALLCONVERSIONRESULT
_CLICKCONVERSION.fields_by_name['gclid'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_CLICKCONVERSION.fields_by_name['conversion_action'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_CLICKCONVERSION.fields_by_name['conversion_date_time'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_CLICKCONVERSION.fields_by_name['conversion_value'].message_type = google_dot_protobuf_dot_wrappers__pb2._DOUBLEVALUE
_CLICKCONVERSION.fields_by_name['currency_code'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_CLICKCONVERSION.fields_by_name['order_id'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_CLICKCONVERSION.fields_by_name['external_attribution_data'].message_type = _EXTERNALATTRIBUTIONDATA
_CALLCONVERSION.fields_by_name['caller_id'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_CALLCONVERSION.fields_by_name['call_start_date_time'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_CALLCONVERSION.fields_by_name['conversion_action'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_CALLCONVERSION.fields_by_name['conversion_date_time'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_CALLCONVERSION.fields_by_name['conversion_value'].message_type = google_dot_protobuf_dot_wrappers__pb2._DOUBLEVALUE
_CALLCONVERSION.fields_by_name['currency_code'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_EXTERNALATTRIBUTIONDATA.fields_by_name['external_attribution_credit'].message_type = google_dot_protobuf_dot_wrappers__pb2._DOUBLEVALUE
_EXTERNALATTRIBUTIONDATA.fields_by_name['external_attribution_model'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_CLICKCONVERSIONRESULT.fields_by_name['gclid'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_CLICKCONVERSIONRESULT.fields_by_name['conversion_action'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_CLICKCONVERSIONRESULT.fields_by_name['conversion_date_time'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_CALLCONVERSIONRESULT.fields_by_name['caller_id'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_CALLCONVERSIONRESULT.fields_by_name['call_start_date_time'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_CALLCONVERSIONRESULT.fields_by_name['conversion_action'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_CALLCONVERSIONRESULT.fields_by_name['conversion_date_time'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
DESCRIPTOR.message_types_by_name['UploadClickConversionsRequest'] = _UPLOADCLICKCONVERSIONSREQUEST
DESCRIPTOR.message_types_by_name['UploadClickConversionsResponse'] = _UPLOADCLICKCONVERSIONSRESPONSE
DESCRIPTOR.message_types_by_name['UploadCallConversionsRequest'] = _UPLOADCALLCONVERSIONSREQUEST
DESCRIPTOR.message_types_by_name['UploadCallConversionsResponse'] = _UPLOADCALLCONVERSIONSRESPONSE
DESCRIPTOR.message_types_by_name['ClickConversion'] = _CLICKCONVERSION
DESCRIPTOR.message_types_by_name['CallConversion'] = _CALLCONVERSION
DESCRIPTOR.message_types_by_name['ExternalAttributionData'] = _EXTERNALATTRIBUTIONDATA
DESCRIPTOR.message_types_by_name['ClickConversionResult'] = _CLICKCONVERSIONRESULT
DESCRIPTOR.message_types_by_name['CallConversionResult'] = _CALLCONVERSIONRESULT
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

UploadClickConversionsRequest = _reflection.GeneratedProtocolMessageType('UploadClickConversionsRequest', (_message.Message,), dict(
  DESCRIPTOR = _UPLOADCLICKCONVERSIONSREQUEST,
  __module__ = 'google.ads.googleads_v2.proto.services.conversion_upload_service_pb2'
  ,
  __doc__ = """Request message for
  [ConversionUploadService.UploadClickConversions][google.ads.googleads.v2.services.ConversionUploadService.UploadClickConversions].
  
  
  Attributes:
      customer_id:
          The ID of the customer performing the upload.
      conversions:
          The conversions that are being uploaded.
      partial_failure:
          If true, successful operations will be carried out and invalid
          operations will return errors. If false, all operations will
          be carried out in one transaction if and only if they are all
          valid. This should always be set to true.
      validate_only:
          If true, the request is validated but not executed. Only
          errors are returned, not results.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v2.services.UploadClickConversionsRequest)
  ))
_sym_db.RegisterMessage(UploadClickConversionsRequest)

UploadClickConversionsResponse = _reflection.GeneratedProtocolMessageType('UploadClickConversionsResponse', (_message.Message,), dict(
  DESCRIPTOR = _UPLOADCLICKCONVERSIONSRESPONSE,
  __module__ = 'google.ads.googleads_v2.proto.services.conversion_upload_service_pb2'
  ,
  __doc__ = """Response message for
  [ConversionUploadService.UploadClickConversions][google.ads.googleads.v2.services.ConversionUploadService.UploadClickConversions].
  
  
  Attributes:
      partial_failure_error:
          Errors that pertain to conversion failures in the partial
          failure mode. Returned when all errors occur inside the
          conversions. If any errors occur outside the conversions (e.g.
          auth errors), we return an RPC level error.
      results:
          Returned for successfully processed conversions. Proto will be
          empty for rows that received an error. Results are not
          returned when validate\_only is true.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v2.services.UploadClickConversionsResponse)
  ))
_sym_db.RegisterMessage(UploadClickConversionsResponse)

UploadCallConversionsRequest = _reflection.GeneratedProtocolMessageType('UploadCallConversionsRequest', (_message.Message,), dict(
  DESCRIPTOR = _UPLOADCALLCONVERSIONSREQUEST,
  __module__ = 'google.ads.googleads_v2.proto.services.conversion_upload_service_pb2'
  ,
  __doc__ = """Request message for
  [ConversionUploadService.UploadCallConversions][google.ads.googleads.v2.services.ConversionUploadService.UploadCallConversions].
  
  
  Attributes:
      customer_id:
          The ID of the customer performing the upload.
      conversions:
          The conversions that are being uploaded.
      partial_failure:
          If true, successful operations will be carried out and invalid
          operations will return errors. If false, all operations will
          be carried out in one transaction if and only if they are all
          valid. This should always be set to true.
      validate_only:
          If true, the request is validated but not executed. Only
          errors are returned, not results.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v2.services.UploadCallConversionsRequest)
  ))
_sym_db.RegisterMessage(UploadCallConversionsRequest)

UploadCallConversionsResponse = _reflection.GeneratedProtocolMessageType('UploadCallConversionsResponse', (_message.Message,), dict(
  DESCRIPTOR = _UPLOADCALLCONVERSIONSRESPONSE,
  __module__ = 'google.ads.googleads_v2.proto.services.conversion_upload_service_pb2'
  ,
  __doc__ = """Response message for
  [ConversionUploadService.UploadCallConversions][google.ads.googleads.v2.services.ConversionUploadService.UploadCallConversions].
  
  
  Attributes:
      partial_failure_error:
          Errors that pertain to conversion failures in the partial
          failure mode. Returned when all errors occur inside the
          conversions. If any errors occur outside the conversions (e.g.
          auth errors), we return an RPC level error.
      results:
          Returned for successfully processed conversions. Proto will be
          empty for rows that received an error. Results are not
          returned when validate\_only is true.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v2.services.UploadCallConversionsResponse)
  ))
_sym_db.RegisterMessage(UploadCallConversionsResponse)

ClickConversion = _reflection.GeneratedProtocolMessageType('ClickConversion', (_message.Message,), dict(
  DESCRIPTOR = _CLICKCONVERSION,
  __module__ = 'google.ads.googleads_v2.proto.services.conversion_upload_service_pb2'
  ,
  __doc__ = """A click conversion.
  
  
  Attributes:
      gclid:
          The Google click ID (gclid) associated with this conversion.
      conversion_action:
          Resource name of the conversion action associated with this
          conversion. Note: Although this resource name consists of a
          customer id and a conversion action id, validation will ignore
          the customer id and use the conversion action id as the sole
          identifier of the conversion action.
      conversion_date_time:
          The date time at which the conversion occurred. Must be after
          the click time. The timezone must be specified. The format is
          "yyyy-mm-dd hh:mm:ss+\|-hh:mm", e.g. “2019-01-01
          12:32:45-08:00”.
      conversion_value:
          The value of the conversion for the advertiser.
      currency_code:
          Currency associated with the conversion value. This is the ISO
          4217 3-character currency code. For example: USD, EUR.
      order_id:
          The order ID associated with the conversion. An order id can
          only be used for one conversion per conversion action.
      external_attribution_data:
          Additional data about externally attributed conversions. This
          field is required for conversions with an externally
          attributed conversion action, but should not be set otherwise.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v2.services.ClickConversion)
  ))
_sym_db.RegisterMessage(ClickConversion)

CallConversion = _reflection.GeneratedProtocolMessageType('CallConversion', (_message.Message,), dict(
  DESCRIPTOR = _CALLCONVERSION,
  __module__ = 'google.ads.googleads_v2.proto.services.conversion_upload_service_pb2'
  ,
  __doc__ = """A call conversion.
  
  
  Attributes:
      caller_id:
          The caller id from which this call was placed. Caller id is
          expected to be in E.164 format with preceding '+' sign. e.g.
          "+16502531234".
      call_start_date_time:
          The date time at which the call occurred. The timezone must be
          specified. The format is "yyyy-mm-dd hh:mm:ss+\|-hh:mm", e.g.
          "2019-01-01 12:32:45-08:00".
      conversion_action:
          Resource name of the conversion action associated with this
          conversion. Note: Although this resource name consists of a
          customer id and a conversion action id, validation will ignore
          the customer id and use the conversion action id as the sole
          identifier of the conversion action.
      conversion_date_time:
          The date time at which the conversion occurred. Must be after
          the call time. The timezone must be specified. The format is
          "yyyy-mm-dd hh:mm:ss+\|-hh:mm", e.g. "2019-01-01
          12:32:45-08:00".
      conversion_value:
          The value of the conversion for the advertiser.
      currency_code:
          Currency associated with the conversion value. This is the ISO
          4217 3-character currency code. For example: USD, EUR.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v2.services.CallConversion)
  ))
_sym_db.RegisterMessage(CallConversion)

ExternalAttributionData = _reflection.GeneratedProtocolMessageType('ExternalAttributionData', (_message.Message,), dict(
  DESCRIPTOR = _EXTERNALATTRIBUTIONDATA,
  __module__ = 'google.ads.googleads_v2.proto.services.conversion_upload_service_pb2'
  ,
  __doc__ = """Contains additional information about externally attributed conversions.
  
  
  Attributes:
      external_attribution_credit:
          Represents the fraction of the conversion that is attributed
          to the Google Ads click.
      external_attribution_model:
          Specifies the attribution model name.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v2.services.ExternalAttributionData)
  ))
_sym_db.RegisterMessage(ExternalAttributionData)

ClickConversionResult = _reflection.GeneratedProtocolMessageType('ClickConversionResult', (_message.Message,), dict(
  DESCRIPTOR = _CLICKCONVERSIONRESULT,
  __module__ = 'google.ads.googleads_v2.proto.services.conversion_upload_service_pb2'
  ,
  __doc__ = """Identifying information for a successfully processed ClickConversion.
  
  
  Attributes:
      gclid:
          The Google Click ID (gclid) associated with this conversion.
      conversion_action:
          Resource name of the conversion action associated with this
          conversion.
      conversion_date_time:
          The date time at which the conversion occurred. The format is
          "yyyy-mm-dd hh:mm:ss+\|-hh:mm", e.g. “2019-01-01
          12:32:45-08:00”.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v2.services.ClickConversionResult)
  ))
_sym_db.RegisterMessage(ClickConversionResult)

CallConversionResult = _reflection.GeneratedProtocolMessageType('CallConversionResult', (_message.Message,), dict(
  DESCRIPTOR = _CALLCONVERSIONRESULT,
  __module__ = 'google.ads.googleads_v2.proto.services.conversion_upload_service_pb2'
  ,
  __doc__ = """Identifying information for a successfully processed
  CallConversionUpload.
  
  
  Attributes:
      caller_id:
          The caller id from which this call was placed. Caller id is
          expected to be in E.164 format with preceding '+' sign.
      call_start_date_time:
          The date time at which the call occurred. The format is "yyyy-
          mm-dd hh:mm:ss+\|-hh:mm", e.g. "2019-01-01 12:32:45-08:00".
      conversion_action:
          Resource name of the conversion action associated with this
          conversion.
      conversion_date_time:
          The date time at which the conversion occurred. The format is
          "yyyy-mm-dd hh:mm:ss+\|-hh:mm", e.g. "2019-01-01
          12:32:45-08:00".
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v2.services.CallConversionResult)
  ))
_sym_db.RegisterMessage(CallConversionResult)


DESCRIPTOR._options = None

_CONVERSIONUPLOADSERVICE = _descriptor.ServiceDescriptor(
  name='ConversionUploadService',
  full_name='google.ads.googleads.v2.services.ConversionUploadService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=_b('\312A\030googleads.googleapis.com'),
  serialized_start=2274,
  serialized_end=2770,
  methods=[
  _descriptor.MethodDescriptor(
    name='UploadClickConversions',
    full_name='google.ads.googleads.v2.services.ConversionUploadService.UploadClickConversions',
    index=0,
    containing_service=None,
    input_type=_UPLOADCLICKCONVERSIONSREQUEST,
    output_type=_UPLOADCLICKCONVERSIONSRESPONSE,
    serialized_options=_b('\202\323\344\223\0029\"4/v2/customers/{customer_id=*}:uploadClickConversions:\001*'),
  ),
  _descriptor.MethodDescriptor(
    name='UploadCallConversions',
    full_name='google.ads.googleads.v2.services.ConversionUploadService.UploadCallConversions',
    index=1,
    containing_service=None,
    input_type=_UPLOADCALLCONVERSIONSREQUEST,
    output_type=_UPLOADCALLCONVERSIONSRESPONSE,
    serialized_options=_b('\202\323\344\223\0028\"3/v2/customers/{customer_id=*}:uploadCallConversions:\001*'),
  ),
])
_sym_db.RegisterServiceDescriptor(_CONVERSIONUPLOADSERVICE)

DESCRIPTOR.services_by_name['ConversionUploadService'] = _CONVERSIONUPLOADSERVICE

# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
import grpc

from google.ads.google_ads.v2.proto.resources import recommendation_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_recommendation__pb2
from google.ads.google_ads.v2.proto.services import recommendation_service_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_recommendation__service__pb2


class RecommendationServiceStub(object):
  """Proto file describing the Recommendation service.

  Service to manage recommendations.
  """

  def __init__(self, channel):
    """Constructor.

    Args:
      channel: A grpc.Channel.
    """
    self.GetRecommendation = channel.unary_unary(
        '/google.ads.googleads.v2.services.RecommendationService/GetRecommendation',
        request_serializer=google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_recommendation__service__pb2.GetRecommendationRequest.SerializeToString,
        response_deserializer=google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_recommendation__pb2.Recommendation.FromString,
        )
    self.ApplyRecommendation = channel.unary_unary(
        '/google.ads.googleads.v2.services.RecommendationService/ApplyRecommendation',
        request_serializer=google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_recommendation__service__pb2.ApplyRecommendationRequest.SerializeToString,
        response_deserializer=google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_recommendation__service__pb2.ApplyRecommendationResponse.FromString,
        )
    self.DismissRecommendation = channel.unary_unary(
        '/google.ads.googleads.v2.services.RecommendationService/DismissRecommendation',
        request_serializer=google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_recommendation__service__pb2.DismissRecommendationRequest.SerializeToString,
        response_deserializer=google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_recommendation__service__pb2.DismissRecommendationResponse.FromString,
        )


class RecommendationServiceServicer(object):
  """Proto file describing the Recommendation service.

  Service to manage recommendations.
  """

  def GetRecommendation(self, request, context):
    """Returns the requested recommendation in full detail.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def ApplyRecommendation(self, request, context):
    """Applies given recommendations with corresponding apply parameters.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def DismissRecommendation(self, request, context):
    """Dismisses given recommendations.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')


def add_RecommendationServiceServicer_to_server(servicer, server):
  rpc_method_handlers = {
      'GetRecommendation': grpc.unary_unary_rpc_method_handler(
          servicer.GetRecommendation,
          request_deserializer=google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_recommendation__service__pb2.GetRecommendationRequest.FromString,
          response_serializer=google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_recommendation__pb2.Recommendation.SerializeToString,
      ),
      'ApplyRecommendation': grpc.unary_unary_rpc_method_handler(
          servicer.ApplyRecommendation,
          request_deserializer=google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_recommendation__service__pb2.ApplyRecommendationRequest.FromString,
          response_serializer=google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_recommendation__service__pb2.ApplyRecommendationResponse.SerializeToString,
      ),
      'DismissRecommendation': grpc.unary_unary_rpc_method_handler(
          servicer.DismissRecommendation,
          request_deserializer=google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_recommendation__service__pb2.DismissRecommendationRequest.FromString,
          response_serializer=google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_recommendation__service__pb2.DismissRecommendationResponse.SerializeToString,
      ),
  }
  generic_handler = grpc.method_handlers_generic_handler(
      'google.ads.googleads.v2.services.RecommendationService', rpc_method_handlers)
  server.add_generic_rpc_handlers((generic_handler,))



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/ads/googleads_v2/proto/resources/ad_group_bid_modifier.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.ads.google_ads.v2.proto.common import criteria_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_common_dot_criteria__pb2
from google.ads.google_ads.v2.proto.enums import bid_modifier_source_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_bid__modifier__source__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='google/ads/googleads_v2/proto/resources/ad_group_bid_modifier.proto',
  package='google.ads.googleads.v2.resources',
  syntax='proto3',
  serialized_options=_b('\n%com.google.ads.googleads.v2.resourcesB\027AdGroupBidModifierProtoP\001ZJgoogle.golang.org/genproto/googleapis/ads/googleads/v2/resources;resources\242\002\003GAA\252\002!Google.Ads.GoogleAds.V2.Resources\312\002!Google\\Ads\\GoogleAds\\V2\\Resources\352\002%Google::Ads::GoogleAds::V2::Resources'),
  serialized_pb=_b('\nCgoogle/ads/googleads_v2/proto/resources/ad_group_bid_modifier.proto\x12!google.ads.googleads.v2.resources\x1a\x33google/ads/googleads_v2/proto/common/criteria.proto\x1a=google/ads/googleads_v2/proto/enums/bid_modifier_source.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1cgoogle/api/annotations.proto\"\xec\x06\n\x12\x41\x64GroupBidModifier\x12\x15\n\rresource_name\x18\x01 \x01(\t\x12.\n\x08\x61\x64_group\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x31\n\x0c\x63riterion_id\x18\x03 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12\x32\n\x0c\x62id_modifier\x18\x04 \x01(\x0b\x32\x1c.google.protobuf.DoubleValue\x12\x33\n\rbase_ad_group\x18\t \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x63\n\x13\x62id_modifier_source\x18\n \x01(\x0e\x32\x46.google.ads.googleads.v2.enums.BidModifierSourceEnum.BidModifierSource\x12_\n\x19hotel_date_selection_type\x18\x05 \x01(\x0b\x32:.google.ads.googleads.v2.common.HotelDateSelectionTypeInfoH\x00\x12\x65\n\x1chotel_advance_booking_window\x18\x06 \x01(\x0b\x32=.google.ads.googleads.v2.common.HotelAdvanceBookingWindowInfoH\x00\x12U\n\x14hotel_length_of_stay\x18\x07 \x01(\x0b\x32\x35.google.ads.googleads.v2.common.HotelLengthOfStayInfoH\x00\x12Q\n\x12hotel_check_in_day\x18\x08 \x01(\x0b\x32\x33.google.ads.googleads.v2.common.HotelCheckInDayInfoH\x00\x12<\n\x06\x64\x65vice\x18\x0b \x01(\x0b\x32*.google.ads.googleads.v2.common.DeviceInfoH\x00\x12Q\n\x11preferred_content\x18\x0c \x01(\x0b\x32\x34.google.ads.googleads.v2.common.PreferredContentInfoH\x00\x42\x0b\n\tcriterionB\x84\x02\n%com.google.ads.googleads.v2.resourcesB\x17\x41\x64GroupBidModifierProtoP\x01ZJgoogle.golang.org/genproto/googleapis/ads/googleads/v2/resources;resources\xa2\x02\x03GAA\xaa\x02!Google.Ads.GoogleAds.V2.Resources\xca\x02!Google\\Ads\\GoogleAds\\V2\\Resources\xea\x02%Google::Ads::GoogleAds::V2::Resourcesb\x06proto3')
  ,
  dependencies=[google_dot_ads_dot_googleads__v2_dot_proto_dot_common_dot_criteria__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_bid__modifier__source__pb2.DESCRIPTOR,google_dot_protobuf_dot_wrappers__pb2.DESCRIPTOR,google_dot_api_dot_annotations__pb2.DESCRIPTOR,])




_ADGROUPBIDMODIFIER = _descriptor.Descriptor(
  name='AdGroupBidModifier',
  full_name='google.ads.googleads.v2.resources.AdGroupBidModifier',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='resource_name', full_name='google.ads.googleads.v2.resources.AdGroupBidModifier.resource_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ad_group', full_name='google.ads.googleads.v2.resources.AdGroupBidModifier.ad_group', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='criterion_id', full_name='google.ads.googleads.v2.resources.AdGroupBidModifier.criterion_id', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='bid_modifier', full_name='google.ads.googleads.v2.resources.AdGroupBidModifier.bid_modifier', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='base_ad_group', full_name='google.ads.googleads.v2.resources.AdGroupBidModifier.base_ad_group', index=4,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='bid_modifier_source', full_name='google.ads.googleads.v2.resources.AdGroupBidModifier.bid_modifier_source', index=5,
      number=10, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='hotel_date_selection_type', full_name='google.ads.googleads.v2.resources.AdGroupBidModifier.hotel_date_selection_type', index=6,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='hotel_advance_booking_window', full_name='google.ads.googleads.v2.resources.AdGroupBidModifier.hotel_advance_booking_window', index=7,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='hotel_length_of_stay', full_name='google.ads.googleads.v2.resources.AdGroupBidModifier.hotel_length_of_stay', index=8,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='hotel_check_in_day', full_name='google.ads.googleads.v2.resources.AdGroupBidModifier.hotel_check_in_day', index=9,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='device', full_name='google.ads.googleads.v2.resources.AdGroupBidModifier.device', index=10,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='preferred_content', full_name='google.ads.googleads.v2.resources.AdGroupBidModifier.preferred_content', index=11,
      number=12, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='criterion', full_name='google.ads.googleads.v2.resources.AdGroupBidModifier.criterion',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=285,
  serialized_end=1161,
)

_ADGROUPBIDMODIFIER.fields_by_name['ad_group'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_ADGROUPBIDMODIFIER.fields_by_name['criterion_id'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_ADGROUPBIDMODIFIER.fields_by_name['bid_modifier'].message_type = google_dot_protobuf_dot_wrappers__pb2._DOUBLEVALUE
_ADGROUPBIDMODIFIER.fields_by_name['base_ad_group'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_ADGROUPBIDMODIFIER.fields_by_name['bid_modifier_source'].enum_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_bid__modifier__source__pb2._BIDMODIFIERSOURCEENUM_BIDMODIFIERSOURCE
_ADGROUPBIDMODIFIER.fields_by_name['hotel_date_selection_type'].message_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_common_dot_criteria__pb2._HOTELDATESELECTIONTYPEINFO
_ADGROUPBIDMODIFIER.fields_by_name['hotel_advance_booking_window'].message_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_common_dot_criteria__pb2._HOTELADVANCEBOOKINGWINDOWINFO
_ADGROUPBIDMODIFIER.fields_by_name['hotel_length_of_stay'].message_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_common_dot_criteria__pb2._HOTELLENGTHOFSTAYINFO
_ADGROUPBIDMODIFIER.fields_by_name['hotel_check_in_day'].message_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_common_dot_criteria__pb2._HOTELCHECKINDAYINFO
_ADGROUPBIDMODIFIER.fields_by_name['device'].message_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_common_dot_criteria__pb2._DEVICEINFO
_ADGROUPBIDMODIFIER.fields_by_name['preferred_content'].message_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_common_dot_criteria__pb2._PREFERREDCONTENTINFO
_ADGROUPBIDMODIFIER.oneofs_by_name['criterion'].fields.append(
  _ADGROUPBIDMODIFIER.fields_by_name['hotel_date_selection_type'])
_ADGROUPBIDMODIFIER.fields_by_name['hotel_date_selection_type'].containing_oneof = _ADGROUPBIDMODIFIER.oneofs_by_name['criterion']
_ADGROUPBIDMODIFIER.oneofs_by_name['criterion'].fields.append(
  _ADGROUPBIDMODIFIER.fields_by_name['hotel_advance_booking_window'])
_ADGROUPBIDMODIFIER.fields_by_name['hotel_advance_booking_window'].containing_oneof = _ADGROUPBIDMODIFIER.oneofs_by_name['criterion']
_ADGROUPBIDMODIFIER.oneofs_by_name['criterion'].fields.append(
  _ADGROUPBIDMODIFIER.fields_by_name['hotel_length_of_stay'])
_ADGROUPBIDMODIFIER.fields_by_name['hotel_length_of_stay'].containing_oneof = _ADGROUPBIDMODIFIER.oneofs_by_name['criterion']
_ADGROUPBIDMODIFIER.oneofs_by_name['criterion'].fields.append(
  _ADGROUPBIDMODIFIER.fields_by_name['hotel_check_in_day'])
_ADGROUPBIDMODIFIER.fields_by_name['hotel_check_in_day'].containing_oneof = _ADGROUPBIDMODIFIER.oneofs_by_name['criterion']
_ADGROUPBIDMODIFIER.oneofs_by_name['criterion'].fields.append(
  _ADGROUPBIDMODIFIER.fields_by_name['device'])
_ADGROUPBIDMODIFIER.fields_by_name['device'].containing_oneof = _ADGROUPBIDMODIFIER.oneofs_by_name['criterion']
_ADGROUPBIDMODIFIER.oneofs_by_name['criterion'].fields.append(
  _ADGROUPBIDMODIFIER.fields_by_name['preferred_content'])
_ADGROUPBIDMODIFIER.fields_by_name['preferred_content'].containing_oneof = _ADGROUPBIDMODIFIER.oneofs_by_name['criterion']
DESCRIPTOR.message_types_by_name['AdGroupBidModifier'] = _ADGROUPBIDMODIFIER
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

AdGroupBidModifier = _reflection.GeneratedProtocolMessageType('AdGroupBidModifier', (_message.Message,), dict(
  DESCRIPTOR = _ADGROUPBIDMODIFIER,
  __module__ = 'google.ads.googleads_v2.proto.resources.ad_group_bid_modifier_pb2'
  ,
  __doc__ = """Represents an ad group bid modifier.
  
  
  Attributes:
      resource_name:
          The resource name of the ad group bid modifier. Ad group bid
          modifier resource names have the form:  ``customers/{customer_
          id}/adGroupBidModifiers/{ad_group_id}~{criterion_id}``
      ad_group:
          The ad group to which this criterion belongs.
      criterion_id:
          The ID of the criterion to bid modify.  This field is ignored
          for mutates.
      bid_modifier:
          The modifier for the bid when the criterion matches. The
          modifier must be in the range: 0.1 - 10.0. The range is 1.0 -
          6.0 for PreferredContent. Use 0 to opt out of a Device type.
      base_ad_group:
          The base ad group from which this draft/trial adgroup bid
          modifier was created. If ad\_group is a base ad group then
          this field will be equal to ad\_group. If the ad group was
          created in the draft or trial and has no corresponding base ad
          group, then this field will be null. This field is readonly.
      bid_modifier_source:
          Bid modifier source.
      criterion:
          The criterion of this ad group bid modifier.
      hotel_date_selection_type:
          Criterion for hotel date selection (default dates vs. user
          selected).
      hotel_advance_booking_window:
          Criterion for number of days prior to the stay the booking is
          being made.
      hotel_length_of_stay:
          Criterion for length of hotel stay in nights.
      hotel_check_in_day:
          Criterion for day of the week the booking is for.
      device:
          A device criterion.
      preferred_content:
          A preferred content criterion.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v2.resources.AdGroupBidModifier)
  ))
_sym_db.RegisterMessage(AdGroupBidModifier)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
import grpc

from google.ads.google_ads.v2.proto.resources import customer_manager_link_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_customer__manager__link__pb2
from google.ads.google_ads.v2.proto.services import customer_manager_link_service_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_customer__manager__link__service__pb2


class CustomerManagerLinkServiceStub(object):
  """Service to manage customer-manager links.
  """

  def __init__(self, channel):
    """Constructor.

    Args:
      channel: A grpc.Channel.
    """
    self.GetCustomerManagerLink = channel.unary_unary(
        '/google.ads.googleads.v2.services.CustomerManagerLinkService/GetCustomerManagerLink',
        request_serializer=google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_customer__manager__link__service__pb2.GetCustomerManagerLinkRequest.SerializeToString,
        response_deserializer=google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_customer__manager__link__pb2.CustomerManagerLink.FromString,
        )
    self.MutateCustomerManagerLink = channel.unary_unary(
        '/google.ads.googleads.v2.services.CustomerManagerLinkService/MutateCustomerManagerLink',
        request_serializer=google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_customer__manager__link__service__pb2.MutateCustomerManagerLinkRequest.SerializeToString,
        response_deserializer=google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_customer__manager__link__service__pb2.MutateCustomerManagerLinkResponse.FromString,
        )


class CustomerManagerLinkServiceServicer(object):
  """Service to manage customer-manager links.
  """

  def GetCustomerManagerLink(self, request, context):
    """Returns the requested CustomerManagerLink in full detail.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def MutateCustomerManagerLink(self, request, context):
    """Creates or updates customer manager links. Operation statuses are returned.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')


def add_CustomerManagerLinkServiceServicer_to_server(servicer, server):
  rpc_method_handlers = {
      'GetCustomerManagerLink': grpc.unary_unary_rpc_method_handler(
          servicer.GetCustomerManagerLink,
          request_deserializer=google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_customer__manager__link__service__pb2.GetCustomerManagerLinkRequest.FromString,
          response_serializer=google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_customer__manager__link__pb2.CustomerManagerLink.SerializeToString,
      ),
      'MutateCustomerManagerLink': grpc.unary_unary_rpc_method_handler(
          servicer.MutateCustomerManagerLink,
          request_deserializer=google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_customer__manager__link__service__pb2.MutateCustomerManagerLinkRequest.FromString,
          response_serializer=google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_customer__manager__link__service__pb2.MutateCustomerManagerLinkResponse.SerializeToString,
      ),
  }
  generic_handler = grpc.method_handlers_generic_handler(
      'google.ads.googleads.v2.services.CustomerManagerLinkService', rpc_method_handlers)
  server.add_generic_rpc_handlers((generic_handler,))



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
import grpc

from google.ads.google_ads.v2.proto.resources import customer_feed_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_customer__feed__pb2
from google.ads.google_ads.v2.proto.services import customer_feed_service_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_customer__feed__service__pb2


class CustomerFeedServiceStub(object):
  """Proto file describing the CustomerFeed service.

  Service to manage customer feeds.
  """

  def __init__(self, channel):
    """Constructor.

    Args:
      channel: A grpc.Channel.
    """
    self.GetCustomerFeed = channel.unary_unary(
        '/google.ads.googleads.v2.services.CustomerFeedService/GetCustomerFeed',
        request_serializer=google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_customer__feed__service__pb2.GetCustomerFeedRequest.SerializeToString,
        response_deserializer=google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_customer__feed__pb2.CustomerFeed.FromString,
        )
    self.MutateCustomerFeeds = channel.unary_unary(
        '/google.ads.googleads.v2.services.CustomerFeedService/MutateCustomerFeeds',
        request_serializer=google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_customer__feed__service__pb2.MutateCustomerFeedsRequest.SerializeToString,
        response_deserializer=google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_customer__feed__service__pb2.MutateCustomerFeedsResponse.FromString,
        )


class CustomerFeedServiceServicer(object):
  """Proto file describing the CustomerFeed service.

  Service to manage customer feeds.
  """

  def GetCustomerFeed(self, request, context):
    """Returns the requested customer feed in full detail.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def MutateCustomerFeeds(self, request, context):
    """Creates, updates, or removes customer feeds. Operation statuses are
    returned.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')


def add_CustomerFeedServiceServicer_to_server(servicer, server):
  rpc_method_handlers = {
      'GetCustomerFeed': grpc.unary_unary_rpc_method_handler(
          servicer.GetCustomerFeed,
          request_deserializer=google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_customer__feed__service__pb2.GetCustomerFeedRequest.FromString,
          response_serializer=google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_customer__feed__pb2.CustomerFeed.SerializeToString,
      ),
      'MutateCustomerFeeds': grpc.unary_unary_rpc_method_handler(
          servicer.MutateCustomerFeeds,
          request_deserializer=google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_customer__feed__service__pb2.MutateCustomerFeedsRequest.FromString,
          response_serializer=google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_customer__feed__service__pb2.MutateCustomerFeedsResponse.SerializeToString,
      ),
  }
  generic_handler = grpc.method_handlers_generic_handler(
      'google.ads.googleads.v2.services.CustomerFeedService', rpc_method_handlers)
  server.add_generic_rpc_handlers((generic_handler,))
